@@ -110,13 +110,17 @@
 #' information is available.}
 #' \item{accrual}{Accrual rate (months) (patient accrual rate per month).}
 #' \item{n.patient}{Average number of patients who were treated at each dose
-#' level}
+#' level in dose-esclation and backfill cohorts}
 #' \item{n.bpatient}{Average number of back filled patients who were treated
 #' at each dose level}
 #' \item{n.tox.patient}{Average number of patients who experienced toxicity at 
-#' each dose level}
+#' each dose level in dose-esclation and backfill cohorts}
 #' \item{n.eff.patient}{Average number of patients who experienced efficacy at 
-#' each dose level}
+#' each dose level in dose-esclation and backfill cohorts}
+#' \item{n.tox.bpatient}{Average number of patients who experienced toxicity at 
+#' each dose level in backfill cohort}
+#' \item{n.eff.bpatient}{Average number of patients who experienced efficacy at 
+#' each dose level in backfill cohort}
 #' \item{prop.select}{Percentage of times that each dose level was selected as
 #' optimal biological dose.}
 #' \item{prop.stop}{Percentage of times that the study was terminated.}
@@ -301,6 +305,9 @@ obd <- array(0,dim=c(n.sim))
 toxicity=matrix(nrow=n.sim,ncol=n.dose)
 efficacy=matrix(nrow=n.sim,ncol=n.dose)
 
+btoxicity=matrix(nrow=n.sim,ncol=n.dose)
+befficacy=matrix(nrow=n.sim,ncol=n.dose)
+
 dose.curr=startdose
 
 backfilltimes=rep(0,n.sim) ## record how may times we back-filled during the trial
@@ -322,6 +329,9 @@ for(simu in 1:n.sim){
   obs.eff.n <- numeric(n.dose)
   pe        <- numeric(n.dose)
   pt        <- numeric(n.dose)
+  
+  obs.btox   <- numeric(n.dose)
+  obs.beff   <- numeric(n.dose)
 
   dose.curr <- startdose
 
@@ -601,8 +611,9 @@ for(simu in 1:n.sim){
                                   endtox = localt.enter+apply(as.matrix(1:cohortsize),1,function(x){min(time.te[x,1],tau.T)}),
                                   dlt    = localt.yT,
                                   endeff = localt.enter+apply(as.matrix(1:cohortsize),1,function(x){min(time.te[x,2],tau.E)}),
-                                  orr    = localt.yE))
-
+                                  orr    = localt.yE,
+                                  backfill = rep(0,cohortsize)))
+      
       if(!is.null(localt.enterb)){
         tite.df <- rbind(tite.df,
                          data.frame(dose   = db,
@@ -610,7 +621,8 @@ for(simu in 1:n.sim){
                                     endtox = localt.enterb+apply(as.matrix(1:length(localt.enterb)),1,function(x){min(time.teba[x,1],tau.T)}),
                                     dlt    = localt.yTb,
                                     endeff = localt.enterb+apply(as.matrix(1:length(localt.enterb)),1,function(x){min(time.teba[x,2],tau.E)}),
-                                    orr    = localt.yEb))
+                                    orr    = localt.yEb,
+                                    backfill = rep(1,length(localt.enterb))))
       }
 
       tite.curdose <- tite.df[tite.df$dose==dose.curr,]
@@ -641,6 +653,12 @@ for(simu in 1:n.sim){
           obs.eff[ds]   <- x.ORR
           obs.eff.n[ds] <- n.ORR
           pe[ds]        <- x.ORR/n.ORR
+          
+          #####create two paramters for -	Average number of patients who experienced toxicity/efficacy at each dose level in backfill cohort####;
+          x.bDLT  <- sum(compsub.T[compsub.T$backfill==1,]$dlt)
+          x.bORR  <- sum(compsub.E[compsub.E$backfill==1,]$orr)
+          obs.btox[ds]   <- x.bDLT
+          obs.beff[ds]   <- x.bORR
 
         }}
 
@@ -784,6 +802,9 @@ for(simu in 1:n.sim){
 
         efficacy[simu,]=obs.eff
         toxicity[simu,]=obs.tox
+        
+        befficacy[simu,]=obs.beff
+        btoxicity[simu,]=obs.btox
 
         backfilltimes[simu]=backfill
         backfillcount[simu,]=backfillvector
@@ -848,6 +869,12 @@ for(simu in 1:n.sim){
         n.eff.patient <- round(apply(efficacy,2,mean),digits=2)
         names(n.eff.patient) <- dose       
 
+        n.tox.bpatient <- round(apply(btoxicity,2,mean),digits=2)
+        names(n.tox.bpatient) <- dose
+        
+        n.eff.bpatient <- round(apply(befficacy,2,mean),digits=2)
+        names(n.eff.bpatient) <- dose   
+        
         duration  <- round(mean(data.dur),digits=1)
         names(duration) <- "Trial duration"
 
@@ -921,6 +948,8 @@ for(simu in 1:n.sim){
                        n.bpatient   = n.bpatient,
                        n.tox.patient= n.tox.patient,
                        n.eff.patient= n.eff.patient,
+                       n.tox.bpatient= n.tox.bpatient,
+                       n.eff.bpatient= n.eff.bpatient,
                        prop.select  = prop.select,
                        prop.stop    = prop.stop,
                        duration     = duration,
