@@ -120,13 +120,17 @@
 #' information is available.}
 #' \item{accrual}{Accrual rate (months) (patient accrual rate per month).}
 #' \item{n.patient}{Average number of patients who were treated at each dose
-#' level}
+#' level in dose-esclation and backfill cohorts}
 #' \item{n.bpatient}{Average number of back filled patients who were treated
 #' at each dose level}
 #' \item{n.tox.patient}{Average number of patients who experienced toxicity at 
-#' each dose level}
+#' each dose level in dose-esclation and backfill cohorts}
 #' \item{n.eff.patient}{Average number of patients who experienced efficacy at 
-#' each dose level}
+#' each dose level in dose-esclation and backfill cohorts}
+#' \item{n.tox.bpatient}{Average number of patients who experienced toxicity at 
+#' each dose level in backfill cohort}
+#' \item{n.eff.bpatient}{Average number of patients who experienced efficacy at 
+#' each dose level in backfill cohort}
 #' \item{prop.select}{Percentage of times that each dose level was selected as
 #' optimal biological dose.}
 #' \item{prop.stop}{Percentage of times that the study was terminated.} 
@@ -371,6 +375,10 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
 
   toxicity=matrix(nrow=an.sim,ncol=n.dose)
   efficacy=matrix(nrow=an.sim,ncol=n.dose)
+  
+  btoxicity=matrix(nrow=an.sim,ncol=n.dose)
+  befficacy=matrix(nrow=an.sim,ncol=n.dose)
+  
 
   prop.select <- array(0,dim=c(an.sim,n.dose))
   prop.stop <- array(0,dim=c(an.sim))
@@ -456,6 +464,9 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
     pe        <- numeric(n.dose)
     pt        <- numeric(n.dose)
 
+    obs.btox   <- numeric(n.dose)
+    obs.beff   <- numeric(n.dose)
+    
     dose.curr <- startdose
 
     bgamma  <- numeric(n.dose)
@@ -734,8 +745,9 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
                                   endtox = localt.enter+apply(as.matrix(1:cohortsize),1,function(x){min(time.te[x,1],tau.T)}),
                                   dlt    = localt.yT,
                                   endeff = localt.enter+apply(as.matrix(1:cohortsize),1,function(x){min(time.te[x,2],tau.E)}),
-                                  orr    = localt.yE))
-
+                                  orr    = localt.yE,
+                                  backfill = rep(0,cohortsize)))
+      
       if(!is.null(localt.enterb)){
         tite.df <- rbind(tite.df,
                          data.frame(dose   = db,
@@ -743,7 +755,8 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
                                     endtox = localt.enterb+apply(as.matrix(1:length(localt.enterb)),1,function(x){min(time.teba[x,1],tau.T)}),
                                     dlt    = localt.yTb,
                                     endeff = localt.enterb+apply(as.matrix(1:length(localt.enterb)),1,function(x){min(time.teba[x,2],tau.E)}),
-                                    orr    = localt.yEb))
+                                    orr    = localt.yEb,
+                                    backfill = rep(1,length(localt.enterb))))
       }
 
       tite.curdose <- tite.df[tite.df$dose==dose.curr,]
@@ -774,6 +787,12 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
           obs.eff[ds]   <- x.ORR
           obs.eff.n[ds] <- n.ORR
           pe[ds]        <- x.ORR/n.ORR
+          
+          #####create two paramters for -	Average number of patients who experienced toxicity/efficacy at each dose level in backfill cohort####;
+          x.bDLT  <- sum(compsub.T[compsub.T$backfill==1,]$dlt)
+          x.bORR  <- sum(compsub.E[compsub.E$backfill==1,]$orr)
+          obs.btox[ds]   <- x.bDLT
+          obs.beff[ds]   <- x.bORR
 
         }}
 
@@ -920,6 +939,10 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
 
     efficacy[simu,]=obs.eff
     toxicity[simu,]=obs.tox
+    
+    befficacy[simu,]=obs.beff
+    btoxicity[simu,]=obs.btox
+    
 
     backfilltimes[simu]=backfill
     backfillcount[simu,]=backfillvector
@@ -985,7 +1008,13 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
   names(n.tox.patient) <- dose
   
   n.eff.patient <- round(apply(efficacy,2,mean),digits=2)
-  names(n.eff.patient) <- dose  
+  names(n.eff.patient) <- dose 
+  
+  n.tox.bpatient <- round(apply(btoxicity,2,mean),digits=2)
+  names(n.tox.bpatient) <- dose
+  
+  n.eff.bpatient <- round(apply(befficacy,2,mean),digits=2)
+  names(n.eff.bpatient) <- dose   
 
   names(toxprob)      <- dose
   names(effprob)      <- dose
@@ -1063,6 +1092,8 @@ get.oc.backboinetr <- function (target_T=0.3,target_Tr=0.359,target_E=0.25,targe
                  n.bpatient   = n.bpatient,
                  n.tox.patient= n.tox.patient,
                  n.eff.patient= n.eff.patient,
+                 n.tox.bpatient= n.tox.bpatient,
+                 n.eff.bpatient= n.eff.bpatient,
                  prop.select  = prop.select,
                  prop.stop    = prop.stop,
                  duration     = duration,
